==> trash-3.0.0.tar.gz: trash/src/EntityQuery/QueryTrait.php <==
<?php

namespace Drupal\trash\EntityQuery;

/**
 * Provides trash-specific helpers for altering entity queries.
 *
 * @property string $entityTypeId
 * @property \Drupal\Core\Entity\EntityTypeInterface $entityType
 * @property \Drupal\Core\Database\Query\ConditionInterface $condition
 */
trait QueryTrait {

  /**
   * Ensures that the query returns only deleted entities.
   *
   * @return $this
   */
  public function isDeleted(): static {
    $this->addMetaData('trash', 'inactive');
    return $this;
  }

  /**
   * Ensures that the query returns only non-deleted entities.
   *
   * @return $this
   */
  public function isNotDeleted(): static {
    $this->addMetaData('trash', 'active');
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareTrash(): static {
    // Do not alter entity revision queries.
    if ($this->allRevisions) {
      return $this;
    }

    /** @var \Drupal\trash\TrashManagerInterface $trash_manager */
    $trash_manager = \Drupal::service('trash.manager');
    if (!$trash_manager->shouldAlterQueries() || !$trash_manager->isEntityTypeEnabled($this->entityType)) {
      return $this;
    }

    $revision_key = $this->entityType->getKey('revision');
    $deleted_key = 'deleted';

    // Skip adding a deleted flag for revisions as well as an explicit filter
    // on deleted, so you can still list deleted content, if needed.
    foreach ($this->condition->conditions() as $condition) {
      // Loading a revision is explicit. So when we try to load one we should do
      // so without a condition on the deleted flag.
      if ($condition['field'] === $revision_key) {
        return $this;
      }
      if ($condition['field'] === $deleted_key) {
        return $this;
      }
    }

    if (!$this->getMetaData('trash')) {
      $this->addMetaData('trash', $trash_manager->getTrashContext());
    }

    if ($this->getMetaData('trash') === 'inactive') {
      $this->exists($deleted_key);
    }
    else {
      $this->notExists($deleted_key);
    }

    return $this;
  }

}

==> trash-3.0.6.tar.gz: trash/src/EntityQuery/QueryTrait.php <==
<?php

namespace Drupal\trash\EntityQuery;

/**
 * Provides trash-specific helpers for altering entity queries.
 *
 * @property string $entityTypeId
 * @property \Drupal\Core\Entity\EntityTypeInterface $entityType
 * @property \Drupal\Core\Database\Query\ConditionInterface $condition
 */
trait QueryTrait {

  /**
   * Ensures that the query returns only deleted entities.
   *
   * @return $this
   */
  public function isDeleted(): static {
    $this->addMetaData('trash', 'inactive');
    return $this;
  }

  /**
   * Ensures that the query returns only non-deleted entities.
   *
   * @return $this
   */
  public function isNotDeleted(): static {
    $this->addMetaData('trash', 'active');
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareTrash(): static {
    /** @var \Drupal\trash\TrashManagerInterface $trash_manager */
    $trash_manager = \Drupal::service('trash.manager');
    if (!$trash_manager->shouldAlterQueries() || !$trash_manager->isEntityTypeEnabled($this->entityType)) {
      return $this;
    }

    // Skip altering queries with an explicit filter on the 'deleted' field, so
    // you can still list deleted content, if needed.
    $deleted_key = 'deleted';
    foreach ($this->condition->conditions() as $condition) {
      if ($condition['field'] === $deleted_key) {
        return $this;
      }
    }

    if (!$this->getMetaData('trash')) {
      $this->addMetaData('trash', $trash_manager->getTrashContext());
    }

    if ($this->getMetaData('trash') === 'inactive') {
      $this->exists($deleted_key);
    }
    else {
      $this->notExists($deleted_key);
    }

    return $this;
  }

}
